@@ -17,7 +17,7 @@ preprocess = transforms.Compose([
     # transforms.Normalize(mean=[0.485, 0.456, 0.406], std=[0.229, 0.224, 0.225]),
 ])
 
-train = FibersDataset(transform=preprocess, random_aug=True)
+train = FibersDataset(transform=preprocess, random_aug=False)
 
 
 lista_fibras = torch.tensor([]);
@@ -28,14 +28,14 @@ for idx,(input_image1, input_image2, classe) in enumerate(train):
     if lista_fibras.shape[0]==300:
         break
 
-lista_a = lista_fibras[250:265]
-lista_b = lista_fibras[250:265]
+lista_a = lista_fibras[240:265]
+lista_b = lista_fibras[240:265]
 
 rotaciona = transforms.Compose([
     transforms.RandomVerticalFlip(p=0.5),
     transforms.RandomHorizontalFlip(p=0.5),
 ])
-lista_b = rotaciona(lista_b)
+# lista_b = rotaciona(lista_b)
 
 distances = np.ones(shape=(lista_a.shape[0],lista_b.shape[0]))
 
@@ -57,7 +57,7 @@ for i in range(lista_a.shape[0]):
             out2 = net.discriminator(out1,out1)
         distances[i][j]= output.cpu().numpy()[0][0]
 
-matches = match_fibers(distances,max_distance=0.80)
+matches = match_fibers(distances,max_distance=0.30)
 print(matches)
 plot_pair_match(matches,lista_a,lista_b)
 print('fim')
\ No newline at end of file
