@@ -11,7 +11,7 @@ from PIL import Image
 from pylabel import importer
 from torchvision import transforms
 from definitions import FIBERS_REPO
-
+from PIL import ImageEnhance
 
 class FibersDataset(torch.utils.data.Dataset):
     """Fibers dataset. to train neural net"""
@@ -32,7 +32,7 @@ class FibersDataset(torch.utils.data.Dataset):
         self.sourceTransform = transform
         self.rootDir = '.'
         self.random_aug = random_aug
-        self.random_aug_prob = 0.8
+        self.random_aug_prob = 0.5
 
     def __len__(self):
         return len(self.data)
@@ -84,7 +84,7 @@ class FibersDataset(torch.utils.data.Dataset):
 
     def random_augmentation(self, img, prob):
         def rotate(img):
-            degrees = [90, 180, 270, 0]
+            degrees = [90, 180, 270]
             index = random.randrange(0, len(degrees))
             return img.rotate(degrees[index])
 
@@ -111,13 +111,42 @@ class FibersDataset(torch.utils.data.Dataset):
             img = cv2.warpAffine(img, mat, (num_cols, num_rows))
             return Image.fromarray(np.uint8(img))
 
+        def contrast(img):
+            levels = [0.3, 0.5, 0.7,1.4]
+            index = random.randrange(0, len(levels))
+            enh = ImageEnhance.Contrast(img)
+            new_img=enh.enhance(levels[index])
+            return new_img
+
+        def color(img):
+            levels = [0.3, 0.5, 0.7,1.4]
+            index = random.randrange(0, len(levels))
+            enh = ImageEnhance.Color(img)
+            new_img=enh.enhance(levels[index])
+            return new_img
+
+        def brightness(img):
+            levels = [0.3, 0.5, 0.7,1.4]
+            index = random.randrange(0, len(levels))
+            enh = ImageEnhance.Brightness(img)
+            new_img=enh.enhance(levels[index])
+            return new_img
+
+        def sharpness(img):
+            levels = [0.3, 0.5, 0.7,1.4]
+            index = random.randrange(0, len(levels))
+            enh = ImageEnhance.Sharpness(img)
+            new_img=enh.enhance(levels[index])
+            return new_img
+
         if random.random() > prob:
             return img
 
         # transform_ops = [flip_tb, flip_lr, rotate,rotate,rotate]
-        transform_ops = [rotate, rotate, rotate]
+        transform_ops = [contrast,color,brightness,sharpness,flip_tb, flip_lr]
         op_len = random.randrange(1, len(transform_ops) + 1)
         ops = random.sample(transform_ops, op_len)
+        ops.append(rotate)
         for op in ops:
             img = op(img)
         return img
